@@ -1,9 +1,9 @@
 package Log::ger::UseDataPrinter;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-04'; # DATE
+our $DATE = '2020-06-06'; # DATE
 our $DIST = 'Log-ger-UseDataPrinter'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Data::Printer ();
 use Log::ger ();
@@ -25,7 +25,7 @@ Log::ger::UseDataPrinter - Use Data::Printer to dump data structures
 
 =head1 VERSION
 
-This document describes version 0.002 of Log::ger::UseDataPrinter (from Perl distribution Log-ger-UseDataPrinter), released on 2020-06-04.
+This document describes version 0.003 of Log::ger::UseDataPrinter (from Perl distribution Log-ger-UseDataPrinter), released on 2020-06-06.
 
 =head1 SYNOPSIS
 
@@ -55,9 +55,29 @@ L<Log::ger>
 
 L<Data::Printer>
 
-Other modules to set data dumper for Log::ger: L<Log::ger::UseDataDump>,
-L<Log::ger::UseDataDumpColor>, L<Log::ger::UseDataDumpObjectAsString>,
-L<Log::ger::UseDataDumpOptions>, L<Log::ger::UseDataDumper>.
+Other modules to set data dumper for Log::ger:
+
+=over
+
+=item * L<Log::ger::UseBaheForDump>
+
+=item * L<Log::ger::UseDataDump>
+
+=item * L<Log::ger::UseDataDumpColor>
+
+=item * L<Log::ger::UseDataDumpObjectAsString>
+
+=item * L<Log::ger::UseDataDumpOptions>
+
+=item * L<Log::ger::UseDataDumper>
+
+=item * L<Log::ger::UseDataDumperCompact>
+
+=item * L<Log::ger::UseJSONForDump>
+
+=item * L<Log::ger::UseYAMLForDump>
+
+=back
 
 =head1 AUTHOR
 
